#---------------------------------------------------
# @(#) config-nokia-nss/M13.5/EngineConfig.pm config-nokia-nss_d1.0.0.latest:cset.003254:2:2@(#) 
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# 
# 
# Copyright (C) IBM Corporation 2008

package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();



#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------

my @rules= (
    {	
        RULE_TYPE               => 'Nokia_XML',
        RULE_DESC               => 'Processing Nokia perf xml-formatted data',
	INPUT_FILE_DESCRIPTION  => [ 
				     '^CDS_\w+_\w+.xml',
				     '^HLR_\w+_\w+.xml',
				     '^MSC_\w+_\w+.xml',
				     ] ,
	
	INPUT_DIR_DEPTH		=> 4 ,
	
	FILENAME_HEADER_FIELDS  => {
				UniqId      => '^*_\w+_(\w+).xml$',
				CaptureTime => '^*_(\w+)_\w+.xml$',
				},
	DIRECTORY_HEADER_FIELDS => {
				NETWORK_ID => '\NETWORK_(\w*)',
				REGION_ID  => '\/REGION_(\w*)',
				},

	XML_HEADER_INFO_FOR_PIF_FILENAME  => [
				        	'startDate',
						'startTime',
						'interval',
						'UniqId',
						'CaptureTime',
        	     				],
        
	XML_HEADER_DATE_TIME_DESCRIPTION  => {
                                      startDate   => '^(\d{4}-\d{2}-\d{2}).*$',
				      startTime   => '^.*T(\d{2}:\d{2}).*$',
                                   },
                                     
	XML_UNIQUE_PIF_BLOCK_ELEMENT_NAMES 	    => ['PMMOResult'],

	XML_UNIQUE_PIF_BLOCK_HEADER_ATTRIBUTE_NAMES =>[
						'interval' ,
	  					'measurementType',
						'startTime',
        						       ],

        XML_OUTPUT_BLOCK_NAME                     => 'Nokia',
	XML_OUTPUT_BLOCK_DESCRIPTION		  => "",
	
	HEADER_DATA_RECORD_PROCESSING => sub {
		my ($blk_name_ref , $h_ref , $d_ref) = @_ ;

		#------------------------------------------------------------------------------
		# To manipulate the OBJECT ID and Identifier to get the counter name and value
		# The manipulation is base on DN , there may DN1, DN2 , DNxxx...
		# -----------------------------------------------------------------------------

		my $count = 0 ;
		my $DN   = 'DN';
		
		my $mtype = $h_ref->{'measurementType'} ;
		while( $d_ref ->{$DN} ne '')
		{
			my @dn_arr = split("/",$d_ref->{$DN}) ;
			for (my $cnt= 0 ; $cnt <= $#dn_arr; $cnt++){
			       	my ($fldName , $fldVal )= split('-',$dn_arr[$cnt],2);
					$fldName = lc($fldName) ;
					if ( $fldName =~ /_code/ ) {
					        $fldName =~ s/_code/c/g ;
					        $fldName .= '_id' ;
					       }
					elsif ( $fldName =~ /code/ ) {
					        $fldName =~ s/code/c/g ;
					        $fldName .= '_id' ;
					       }
					elsif( $fldName eq 'd_ch'){
					       $fldName = 'dchannel_id' ;
					}
					elsif( $fldName eq 'cgr'){	
					       $fldName = 'alt_id' ;
					}
					elsif( $fldName eq 'cgrname') {
					       $fldName = 'attr_name' ;
					}
					# FOR UTRAiHLR and UTRAMSC
					elsif( $fldName eq 'sio') {
						$fldName = 'spc_id' ;
						if($mtype eq 'UTRAHLR' or $mtype eq 'UTRAMSC')
						{
							$d_ref->{'sio_id'} = $fldVal ;

						}
					}
					elsif( $fldName eq 'slsn') {
						$fldName .= '_id' ;
						$d_ref->{'sln_id'}= $fldVal ;
					}
					elsif( $fldName eq 'cds'){
						if( $mtype eq 'CGRC')
						{
							$fldName = 'msc_id' ;
						}else
						{
							$fldName .= '_id';
						}
					}
					elsif( $fldName eq 'plmnname'){
						$fldName .= '_id';
						$fldVal  =~ s/ /_/g;
						$fldVal =~ s/"//g;
					}
					elsif( $fldName eq '"plmn'){
						$fldName = s/"//g;
					}
					#------------------------------------------
					# FOR measurementype CDATA has this format :
					# PLMN-PLMN/PLMNNAME-GREECE/-VF
					# so for plmnname_id = GREECE_VF
					#------------------------------------------
					elsif( $fldName eq ''){
						if ($mtype eq 'PLMNV'){
							my $tmpfldVal = $d_ref->{'plmnname_id'} ;
							my $sign = "_";
							$fldName = 'plmnname_id';
						        $fldVal="$tmpfldVal$sign$fldVal";
						}
					}
					else { $fldName .= '_id' }

					$d_ref->{$fldName} = $fldVal ;
					delete $d_ref->{$DN} ;
			}

			$count++ ;
			$DN="DN$count";

		} 


		#-----------------------------------------------------------------------------
		# To convert the scientific value to integer , eg 2.08557e+06 = 2085570
		# ----------------------------------------------------------------------------
		foreach my $key (keys %{$d_ref}) {
			if($d_ref->{$key} =~ /^-?\d/){
				if($d_ref->{$key} =~ '[+]'){
					$d_ref->{$key} = $d_ref->{$key} * 1 ;
				}else {
					$d_ref->{$key} = $d_ref->{$key};
				}
			}else
			{
				$d_ref->{$key} = $d_ref->{$key} ;
			}
		}


		#---------------------------------------------------------
		# Get Counter ID , for Block Name mapping 
		#---------------------------------------------------------
		my $str    = $h_ref->{'measurementType'};
		$$blk_name_ref = $str ;

                return 0;
	},

    },

    {	
        RULE_TYPE               => 'Nokia_XML',
        RULE_DESC               => 'Processing Nokia perf xml-formatted data',
	INPUT_FILE_DESCRIPTION  => '^etlexpmx_\w+_\w+_\w+.xml',
	
	INPUT_DIR_DEPTH		=> 3 ,
	
	FILENAME_HEADER_FIELDS  => {
				UniqId      => '^*_\w+_(\w+).xml$',
				CaptureTime => '^etlexpmx_\w+_(\w+)_\w+.xml'
			},
	DIRECTORY_HEADER_FIELDS => {
				NETWORK_ID => '\/NETWORK_(\w*)',
				REGION_ID  => '/REGION_(\w*)',
			},

	XML_HEADER_INFO_FOR_PIF_FILENAME  => [
				        	'startDate',
						'startTime',
						'interval',
						'UniqId',
						'CaptureTime',
       	     				],
        
	XML_HEADER_DATE_TIME_DESCRIPTION  => {
                                      startDate   => '^(\d{4}-\d{2}-\d{2}).*$',
				      startTime       => '^.*T(\d{2}:\d{2}).*$',
                                   },
                                     
	XML_UNIQUE_PIF_BLOCK_ELEMENT_NAMES 	    => ['PMMOResult'],

	XML_UNIQUE_PIF_BLOCK_HEADER_ATTRIBUTE_NAMES =>[
						'interval' ,
	  					'measurementType',
						'startTime',
        						       ],

        XML_OUTPUT_BLOCK_NAME                     => 'Nokia',
	XML_OUTPUT_BLOCK_DESCRIPTION		  => "",
	
	HEADER_DATA_RECORD_PROCESSING => sub {
		my ($blk_name_ref , $h_ref , $d_ref) = @_ ;

		#------------------------------------------------------------------------------
		# To manipulate the OBJECT ID and Identifier to get the counter name and value
		# The manipulation is base on DN , there may DN1, DN2 , DNxxx...
		# -----------------------------------------------------------------------------

		my $count = 0 ;
		my $DN   = 'DN';
		
		my $mtype = $h_ref->{'measurementType'} ;
		while( $d_ref ->{$DN} ne '')
		{

			my @dn_arr = split("/",$d_ref->{$DN}) ;
			for (my $cnt= 0 ; $cnt <= $#dn_arr; $cnt++){
			       	my ($fldName , $fldVal )= split('-',$dn_arr[$cnt],2);
					$fldName = lc($fldName) ;
					if ( $fldName =~ /_code/ ) {
					        $fldName =~ s/_code/c/g ;
					        $fldName .= '_id' ;
					       }
					elsif( $fldName eq 'dchannel'){
					       $fldName = 'dch_id' ;
					}
                                        elsif( $fldName eq 'd_ch'){
                                               $fldName = 'dch_id' ;
                                        }
                                        elsif( $fldName eq 'security_event'){
                                               $fldName = 'secevnt_id' ;
                                        }
					elsif( $fldName eq 'plmnname'){
						$fldName .= '_id';
  						$fldVal   =~ s/ /_/g ;
						$fldVal   =~ s/"//g ;
					}
					elsif( $fldName eq '"plmn'){
						$fldName = s/"//g ;	
					}
					#------------------------------------------
					# FOR measurementype CDATA has this format :
					# PLMN-PLMN/PLMNNAME-GREECE/-VF
					# so for plmnname_id = GREECE_VF
					#------------------------------------------
					elsif( $fldName eq ''){
						if ($mtype eq 'PLMNV'){
							my $tmpfldVal = $d_ref->{'plmnname_id'} ;
							my $sign = "_";
							$fldName = 'plmnname_id';
						        $fldVal="$tmpfldVal$sign$fldVal";
						}
					}
					else { $fldName .= '_id' }

					$d_ref->{$fldName} = $fldVal ;
					delete $d_ref->{$DN} ;
			}

			$count++ ;
			$DN="DN$count";

		} 


		#-----------------------------------------------------------------------------
		# To convert the scientific value to integer , eg 2.08557e+06 = 2085570
		# ----------------------------------------------------------------------------
		foreach my $key (keys %{$d_ref}) {
			#$d_ref->{$key} = $d_ref->{$key} * 1 ;
			  if($d_ref->{$key} =~ /^-?\d/){
			  	if($d_ref->{$key} =~ '[+]'){
			 		$d_ref->{$key} = $d_ref->{$key} * 1 ;
				} else
				{
					$d_ref->{$key} = $d_ref->{$key} ;

					}
			  }else
			  {
			  	$d_ref->{$key} = $d_ref->{$key} ;
				}
		}

		#---------------------------------------------------------
		# Get Counter ID , for Block Name mapping 
		#---------------------------------------------------------
		my $str    = $h_ref->{'measurementType'};
		$$blk_name_ref = $str ;

                return 0;
	},

    },
);


sub engine_config {

   return \@rules;
}

1;
